Class: OnlinePayments::SDK::Domain::AirlineFlightLeg
- Inherits:
-
DataObject
- Object
- DataObject
- OnlinePayments::SDK::Domain::AirlineFlightLeg
- Defined in:
- lib/onlinepayments/sdk/domain/airline_flight_leg.rb
Instance Attribute Summary collapse
-
#airline_class ⇒ String?
The current value of airline_class.
-
#arrival_airport ⇒ String?
The current value of arrival_airport.
-
#arrival_time ⇒ String?
The current value of arrival_time.
-
#carrier_code ⇒ String?
The current value of carrier_code.
-
#conjunction_ticket ⇒ String?
The current value of conjunction_ticket.
-
#coupon_number ⇒ String?
The current value of coupon_number.
-
#date ⇒ String?
The current value of date.
-
#departure_time ⇒ String?
The current value of departure_time.
-
#endorsement_or_restriction ⇒ String?
The current value of endorsement_or_restriction.
-
#exchange_ticket ⇒ String?
The current value of exchange_ticket.
-
#fare ⇒ Object
deprecated
Deprecated.
Use legFare instead. Fare of this leg
-
#fare_basis ⇒ String?
The current value of fare_basis.
-
#fee ⇒ Integer?
The current value of fee.
-
#flight_code ⇒ String?
The current value of flight_code.
-
#flight_number ⇒ String?
The current value of flight_number.
-
#leg_fare ⇒ Integer?
The current value of leg_fare.
-
#number ⇒ Object
deprecated
Deprecated.
This field is not used by any payment product Sequence number of the flight leg
-
#origin_airport ⇒ String?
The current value of origin_airport.
-
#passenger_class ⇒ String?
The current value of passenger_class.
-
#stopover_code ⇒ String?
The current value of stopover_code.
-
#taxes ⇒ Integer?
The current value of taxes.
Instance Method Summary collapse
Methods inherited from DataObject
Instance Attribute Details
#airline_class ⇒ String?
Returns the current value of airline_class.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def airline_class @airline_class end |
#arrival_airport ⇒ String?
Returns the current value of arrival_airport.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def arrival_airport @arrival_airport end |
#arrival_time ⇒ String?
Returns the current value of arrival_time.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def arrival_time @arrival_time end |
#carrier_code ⇒ String?
Returns the current value of carrier_code.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def carrier_code @carrier_code end |
#conjunction_ticket ⇒ String?
Returns the current value of conjunction_ticket.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def conjunction_ticket @conjunction_ticket end |
#coupon_number ⇒ String?
Returns the current value of coupon_number.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def coupon_number @coupon_number end |
#date ⇒ String?
Returns the current value of date.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def date @date end |
#departure_time ⇒ String?
Returns the current value of departure_time.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def departure_time @departure_time end |
#endorsement_or_restriction ⇒ String?
Returns the current value of endorsement_or_restriction.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def endorsement_or_restriction @endorsement_or_restriction end |
#exchange_ticket ⇒ String?
Returns the current value of exchange_ticket.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def exchange_ticket @exchange_ticket end |
#fare ⇒ Object
Use legFare instead. Fare of this leg
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def fare @fare end |
#fare_basis ⇒ String?
Returns the current value of fare_basis.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def fare_basis @fare_basis end |
#fee ⇒ Integer?
Returns the current value of fee.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def fee @fee end |
#flight_code ⇒ String?
Returns the current value of flight_code.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def flight_code @flight_code end |
#flight_number ⇒ String?
Returns the current value of flight_number.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def flight_number @flight_number end |
#leg_fare ⇒ Integer?
Returns the current value of leg_fare.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def leg_fare @leg_fare end |
#number ⇒ Object
This field is not used by any payment product Sequence number of the flight leg
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def number @number end |
#origin_airport ⇒ String?
Returns the current value of origin_airport.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def origin_airport @origin_airport end |
#passenger_class ⇒ String?
Returns the current value of passenger_class.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def passenger_class @passenger_class end |
#stopover_code ⇒ String?
Returns the current value of stopover_code.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def stopover_code @stopover_code end |
#taxes ⇒ Integer?
Returns the current value of taxes.
30 31 32 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 30 def taxes @taxes end |
Instance Method Details
#from_hash(hash) ⇒ Object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 103 def from_hash(hash) super if hash.has_key? 'airlineClass' @airline_class = hash['airlineClass'] end if hash.has_key? 'arrivalAirport' @arrival_airport = hash['arrivalAirport'] end if hash.has_key? 'arrivalTime' @arrival_time = hash['arrivalTime'] end if hash.has_key? 'carrierCode' @carrier_code = hash['carrierCode'] end if hash.has_key? 'conjunctionTicket' @conjunction_ticket = hash['conjunctionTicket'] end if hash.has_key? 'couponNumber' @coupon_number = hash['couponNumber'] end if hash.has_key? 'date' @date = hash['date'] end if hash.has_key? 'departureTime' @departure_time = hash['departureTime'] end if hash.has_key? 'endorsementOrRestriction' @endorsement_or_restriction = hash['endorsementOrRestriction'] end if hash.has_key? 'exchangeTicket' @exchange_ticket = hash['exchangeTicket'] end if hash.has_key? 'fare' @fare = hash['fare'] end if hash.has_key? 'fareBasis' @fare_basis = hash['fareBasis'] end if hash.has_key? 'fee' @fee = hash['fee'] end if hash.has_key? 'flightCode' @flight_code = hash['flightCode'] end if hash.has_key? 'flightNumber' @flight_number = hash['flightNumber'] end if hash.has_key? 'legFare' @leg_fare = hash['legFare'] end if hash.has_key? 'number' @number = hash['number'] end if hash.has_key? 'originAirport' @origin_airport = hash['originAirport'] end if hash.has_key? 'passengerClass' @passenger_class = hash['passengerClass'] end if hash.has_key? 'stopoverCode' @stopover_code = hash['stopoverCode'] end if hash.has_key? 'taxes' @taxes = hash['taxes'] end end |
#to_h ⇒ Hash
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/onlinepayments/sdk/domain/airline_flight_leg.rb', line 77 def to_h hash = super hash['airlineClass'] = @airline_class unless @airline_class.nil? hash['arrivalAirport'] = @arrival_airport unless @arrival_airport.nil? hash['arrivalTime'] = @arrival_time unless @arrival_time.nil? hash['carrierCode'] = @carrier_code unless @carrier_code.nil? hash['conjunctionTicket'] = @conjunction_ticket unless @conjunction_ticket.nil? hash['couponNumber'] = @coupon_number unless @coupon_number.nil? hash['date'] = @date unless @date.nil? hash['departureTime'] = @departure_time unless @departure_time.nil? hash['endorsementOrRestriction'] = @endorsement_or_restriction unless @endorsement_or_restriction.nil? hash['exchangeTicket'] = @exchange_ticket unless @exchange_ticket.nil? hash['fare'] = @fare unless @fare.nil? hash['fareBasis'] = @fare_basis unless @fare_basis.nil? hash['fee'] = @fee unless @fee.nil? hash['flightCode'] = @flight_code unless @flight_code.nil? hash['flightNumber'] = @flight_number unless @flight_number.nil? hash['legFare'] = @leg_fare unless @leg_fare.nil? hash['number'] = @number unless @number.nil? hash['originAirport'] = @origin_airport unless @origin_airport.nil? hash['passengerClass'] = @passenger_class unless @passenger_class.nil? hash['stopoverCode'] = @stopover_code unless @stopover_code.nil? hash['taxes'] = @taxes unless @taxes.nil? hash end |