Class: OnlinePayments::SDK::Domain::CardPaymentMethodSpecificInput

Inherits:
DataObject
  • Object
show all
Defined in:
lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from DataObject

new_from_hash

Instance Attribute Details

#allow_dynamic_linkingtrue/false?

Returns the current value of allow_dynamic_linking.

Returns:

  • (true/false, nil)

    the current value of allow_dynamic_linking



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def allow_dynamic_linking
  @allow_dynamic_linking
end

#authorization_modeString?

Returns the current value of authorization_mode.

Returns:

  • (String, nil)

    the current value of authorization_mode



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def authorization_mode
  @authorization_mode
end

#auto_captureOnlinePayments::SDK::Domain::AutoCapture?

Returns the current value of auto_capture.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def auto_capture
  @auto_capture
end

#cardOnlinePayments::SDK::Domain::Card?

Returns the current value of card.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def card
  @card
end

#card_on_file_recurring_expirationString?

Returns the current value of card_on_file_recurring_expiration.

Returns:

  • (String, nil)

    the current value of card_on_file_recurring_expiration



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def card_on_file_recurring_expiration
  @card_on_file_recurring_expiration
end

#card_on_file_recurring_frequencyString?

Returns the current value of card_on_file_recurring_frequency.

Returns:

  • (String, nil)

    the current value of card_on_file_recurring_frequency



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def card_on_file_recurring_frequency
  @card_on_file_recurring_frequency
end

#cobrand_selection_indicatorString?

Returns the current value of cobrand_selection_indicator.

Returns:

  • (String, nil)

    the current value of cobrand_selection_indicator



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def cobrand_selection_indicator
  @cobrand_selection_indicator
end

#currency_conversionOnlinePayments::SDK::Domain::CurrencyConversionInput?

Returns the current value of currency_conversion.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def currency_conversion
  @currency_conversion
end

#initial_scheme_transaction_idString?

Returns the current value of initial_scheme_transaction_id.

Returns:

  • (String, nil)

    the current value of initial_scheme_transaction_id



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def initial_scheme_transaction_id
  @initial_scheme_transaction_id
end

#is_recurringtrue/false?

Returns the current value of is_recurring.

Returns:

  • (true/false, nil)

    the current value of is_recurring



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def is_recurring
  @is_recurring
end

#market_placeOnlinePayments::SDK::Domain::MarketPlace?

Returns the current value of market_place.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def market_place
  @market_place
end

#multiple_payment_informationOnlinePayments::SDK::Domain::MultiplePaymentInformation?

Returns the current value of multiple_payment_information.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def multiple_payment_information
  @multiple_payment_information
end

#network_token_dataOnlinePayments::SDK::Domain::NetworkTokenData?

Returns the current value of network_token_data.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def network_token_data
  @network_token_data
end

#payment_product130_specific_inputOnlinePayments::SDK::Domain::PaymentProduct130SpecificInput?

Returns the current value of payment_product130_specific_input.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def payment_product130_specific_input
  @payment_product130_specific_input
end

#payment_product3012_specific_inputOnlinePayments::SDK::Domain::PaymentProduct3012SpecificInput?

Returns the current value of payment_product3012_specific_input.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def payment_product3012_specific_input
  @payment_product3012_specific_input
end

#payment_product3013_specific_inputOnlinePayments::SDK::Domain::PaymentProduct3013SpecificInput?

Returns the current value of payment_product3013_specific_input.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def payment_product3013_specific_input
  @payment_product3013_specific_input
end

#payment_product3208_specific_inputOnlinePayments::SDK::Domain::PaymentProduct3208SpecificInput?

Returns the current value of payment_product3208_specific_input.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def payment_product3208_specific_input
  @payment_product3208_specific_input
end

#payment_product3209_specific_inputOnlinePayments::SDK::Domain::PaymentProduct3209SpecificInput?

Returns the current value of payment_product3209_specific_input.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def payment_product3209_specific_input
  @payment_product3209_specific_input
end

#payment_product5002_specific_inputOnlinePayments::SDK::Domain::PaymentProduct5002SpecificInput?

Returns the current value of payment_product5002_specific_input.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def payment_product5002_specific_input
  @payment_product5002_specific_input
end

#payment_product_idInteger?

Returns the current value of payment_product_id.

Returns:

  • (Integer, nil)

    the current value of payment_product_id



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def payment_product_id
  @payment_product_id
end

#recurringOnlinePayments::SDK::Domain::CardRecurrenceDetails?

Returns the current value of recurring.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def recurring
  @recurring
end

#return_urlString?

Returns the current value of return_url.

Returns:

  • (String, nil)

    the current value of return_url



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def return_url
  @return_url
end

#scheme_reference_dataString?

Returns the current value of scheme_reference_data.

Returns:

  • (String, nil)

    the current value of scheme_reference_data



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def scheme_reference_data
  @scheme_reference_data
end

#skip_authenticationObject

Deprecated.

Use threeDSecure.skipAuthentication instead. * true = 3D Secure authentication will be skipped for this transaction. This setting should be used when isRecurring is set to true and recurringPaymentSequenceIndicator is set to recurring. * false = 3D Secure authentication will not be skipped for this transaction. Note: This is only possible if your account in our system is setup for 3D Secure authentication and if your configuration in our system allows you to override it per transaction.



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def skip_authentication
  @skip_authentication
end

#sub_merchantOnlinePayments::SDK::Domain::SubMerchant?

Returns the current value of sub_merchant.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def sub_merchant
  @sub_merchant
end

#three_d_secureOnlinePayments::SDK::Domain::ThreeDSecure?

Returns the current value of three_d_secure.

Returns:



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def three_d_secure
  @three_d_secure
end

#tokenString?

Returns the current value of token.

Returns:

  • (String, nil)

    the current value of token



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def token
  @token
end

#tokenizetrue/false?

Returns the current value of tokenize.

Returns:

  • (true/false, nil)

    the current value of tokenize



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def tokenize
  @tokenize
end

#transaction_channelString?

Returns the current value of transaction_channel.

Returns:

  • (String, nil)

    the current value of transaction_channel



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def transaction_channel
  @transaction_channel
end

#unscheduled_card_on_file_requestorString?

Returns the current value of unscheduled_card_on_file_requestor.

Returns:

  • (String, nil)

    the current value of unscheduled_card_on_file_requestor



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def unscheduled_card_on_file_requestor
  @unscheduled_card_on_file_requestor
end

#unscheduled_card_on_file_sequence_indicatorString?

Returns the current value of unscheduled_card_on_file_sequence_indicator.

Returns:

  • (String, nil)

    the current value of unscheduled_card_on_file_sequence_indicator



55
56
57
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 55

def unscheduled_card_on_file_sequence_indicator
  @unscheduled_card_on_file_sequence_indicator
end

Instance Method Details

#from_hash(hash) ⇒ Object



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 157

def from_hash(hash)
  super
  if hash.has_key? 'allowDynamicLinking'
    @allow_dynamic_linking = hash['allowDynamicLinking']
  end
  if hash.has_key? 'authorizationMode'
    @authorization_mode = hash['authorizationMode']
  end
  if hash.has_key? 'autoCapture'
    raise TypeError, "value '%s' is not a Hash" % [hash['autoCapture']] unless hash['autoCapture'].is_a? Hash
    @auto_capture = OnlinePayments::SDK::Domain::AutoCapture.new_from_hash(hash['autoCapture'])
  end
  if hash.has_key? 'card'
    raise TypeError, "value '%s' is not a Hash" % [hash['card']] unless hash['card'].is_a? Hash
    @card = OnlinePayments::SDK::Domain::Card.new_from_hash(hash['card'])
  end
  if hash.has_key? 'cardOnFileRecurringExpiration'
    @card_on_file_recurring_expiration = hash['cardOnFileRecurringExpiration']
  end
  if hash.has_key? 'cardOnFileRecurringFrequency'
    @card_on_file_recurring_frequency = hash['cardOnFileRecurringFrequency']
  end
  if hash.has_key? 'cobrandSelectionIndicator'
    @cobrand_selection_indicator = hash['cobrandSelectionIndicator']
  end
  if hash.has_key? 'currencyConversion'
    raise TypeError, "value '%s' is not a Hash" % [hash['currencyConversion']] unless hash['currencyConversion'].is_a? Hash
    @currency_conversion = OnlinePayments::SDK::Domain::CurrencyConversionInput.new_from_hash(hash['currencyConversion'])
  end
  if hash.has_key? 'initialSchemeTransactionId'
    @initial_scheme_transaction_id = hash['initialSchemeTransactionId']
  end
  if hash.has_key? 'isRecurring'
    @is_recurring = hash['isRecurring']
  end
  if hash.has_key? 'marketPlace'
    raise TypeError, "value '%s' is not a Hash" % [hash['marketPlace']] unless hash['marketPlace'].is_a? Hash
    @market_place = OnlinePayments::SDK::Domain::MarketPlace.new_from_hash(hash['marketPlace'])
  end
  if hash.has_key? 'multiplePaymentInformation'
    raise TypeError, "value '%s' is not a Hash" % [hash['multiplePaymentInformation']] unless hash['multiplePaymentInformation'].is_a? Hash
    @multiple_payment_information = OnlinePayments::SDK::Domain::MultiplePaymentInformation.new_from_hash(hash['multiplePaymentInformation'])
  end
  if hash.has_key? 'networkTokenData'
    raise TypeError, "value '%s' is not a Hash" % [hash['networkTokenData']] unless hash['networkTokenData'].is_a? Hash
    @network_token_data = OnlinePayments::SDK::Domain::NetworkTokenData.new_from_hash(hash['networkTokenData'])
  end
  if hash.has_key? 'paymentProduct130SpecificInput'
    raise TypeError, "value '%s' is not a Hash" % [hash['paymentProduct130SpecificInput']] unless hash['paymentProduct130SpecificInput'].is_a? Hash
    @payment_product130_specific_input = OnlinePayments::SDK::Domain::PaymentProduct130SpecificInput.new_from_hash(hash['paymentProduct130SpecificInput'])
  end
  if hash.has_key? 'paymentProduct3012SpecificInput'
    raise TypeError, "value '%s' is not a Hash" % [hash['paymentProduct3012SpecificInput']] unless hash['paymentProduct3012SpecificInput'].is_a? Hash
    @payment_product3012_specific_input = OnlinePayments::SDK::Domain::PaymentProduct3012SpecificInput.new_from_hash(hash['paymentProduct3012SpecificInput'])
  end
  if hash.has_key? 'paymentProduct3013SpecificInput'
    raise TypeError, "value '%s' is not a Hash" % [hash['paymentProduct3013SpecificInput']] unless hash['paymentProduct3013SpecificInput'].is_a? Hash
    @payment_product3013_specific_input = OnlinePayments::SDK::Domain::PaymentProduct3013SpecificInput.new_from_hash(hash['paymentProduct3013SpecificInput'])
  end
  if hash.has_key? 'paymentProduct3208SpecificInput'
    raise TypeError, "value '%s' is not a Hash" % [hash['paymentProduct3208SpecificInput']] unless hash['paymentProduct3208SpecificInput'].is_a? Hash
    @payment_product3208_specific_input = OnlinePayments::SDK::Domain::PaymentProduct3208SpecificInput.new_from_hash(hash['paymentProduct3208SpecificInput'])
  end
  if hash.has_key? 'paymentProduct3209SpecificInput'
    raise TypeError, "value '%s' is not a Hash" % [hash['paymentProduct3209SpecificInput']] unless hash['paymentProduct3209SpecificInput'].is_a? Hash
    @payment_product3209_specific_input = OnlinePayments::SDK::Domain::PaymentProduct3209SpecificInput.new_from_hash(hash['paymentProduct3209SpecificInput'])
  end
  if hash.has_key? 'paymentProduct5002SpecificInput'
    raise TypeError, "value '%s' is not a Hash" % [hash['paymentProduct5002SpecificInput']] unless hash['paymentProduct5002SpecificInput'].is_a? Hash
    @payment_product5002_specific_input = OnlinePayments::SDK::Domain::PaymentProduct5002SpecificInput.new_from_hash(hash['paymentProduct5002SpecificInput'])
  end
  if hash.has_key? 'paymentProductId'
    @payment_product_id = hash['paymentProductId']
  end
  if hash.has_key? 'recurring'
    raise TypeError, "value '%s' is not a Hash" % [hash['recurring']] unless hash['recurring'].is_a? Hash
    @recurring = OnlinePayments::SDK::Domain::CardRecurrenceDetails.new_from_hash(hash['recurring'])
  end
  if hash.has_key? 'returnUrl'
    @return_url = hash['returnUrl']
  end
  if hash.has_key? 'schemeReferenceData'
    @scheme_reference_data = hash['schemeReferenceData']
  end
  if hash.has_key? 'skipAuthentication'
    @skip_authentication = hash['skipAuthentication']
  end
  if hash.has_key? 'subMerchant'
    raise TypeError, "value '%s' is not a Hash" % [hash['subMerchant']] unless hash['subMerchant'].is_a? Hash
    @sub_merchant = OnlinePayments::SDK::Domain::SubMerchant.new_from_hash(hash['subMerchant'])
  end
  if hash.has_key? 'threeDSecure'
    raise TypeError, "value '%s' is not a Hash" % [hash['threeDSecure']] unless hash['threeDSecure'].is_a? Hash
    @three_d_secure = OnlinePayments::SDK::Domain::ThreeDSecure.new_from_hash(hash['threeDSecure'])
  end
  if hash.has_key? 'token'
    @token = hash['token']
  end
  if hash.has_key? 'tokenize'
    @tokenize = hash['tokenize']
  end
  if hash.has_key? 'transactionChannel'
    @transaction_channel = hash['transactionChannel']
  end
  if hash.has_key? 'unscheduledCardOnFileRequestor'
    @unscheduled_card_on_file_requestor = hash['unscheduledCardOnFileRequestor']
  end
  if hash.has_key? 'unscheduledCardOnFileSequenceIndicator'
    @unscheduled_card_on_file_sequence_indicator = hash['unscheduledCardOnFileSequenceIndicator']
  end
end

#to_hHash

Returns:

  • (Hash)


121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/onlinepayments/sdk/domain/card_payment_method_specific_input.rb', line 121

def to_h
  hash = super
  hash['allowDynamicLinking'] = @allow_dynamic_linking unless @allow_dynamic_linking.nil?
  hash['authorizationMode'] = @authorization_mode unless @authorization_mode.nil?
  hash['autoCapture'] = @auto_capture.to_h unless @auto_capture.nil?
  hash['card'] = @card.to_h unless @card.nil?
  hash['cardOnFileRecurringExpiration'] = @card_on_file_recurring_expiration unless @card_on_file_recurring_expiration.nil?
  hash['cardOnFileRecurringFrequency'] = @card_on_file_recurring_frequency unless @card_on_file_recurring_frequency.nil?
  hash['cobrandSelectionIndicator'] = @cobrand_selection_indicator unless @cobrand_selection_indicator.nil?
  hash['currencyConversion'] = @currency_conversion.to_h unless @currency_conversion.nil?
  hash['initialSchemeTransactionId'] = @initial_scheme_transaction_id unless @initial_scheme_transaction_id.nil?
  hash['isRecurring'] = @is_recurring unless @is_recurring.nil?
  hash['marketPlace'] = @market_place.to_h unless @market_place.nil?
  hash['multiplePaymentInformation'] = @multiple_payment_information.to_h unless @multiple_payment_information.nil?
  hash['networkTokenData'] = @network_token_data.to_h unless @network_token_data.nil?
  hash['paymentProduct130SpecificInput'] = @payment_product130_specific_input.to_h unless @payment_product130_specific_input.nil?
  hash['paymentProduct3012SpecificInput'] = @payment_product3012_specific_input.to_h unless @payment_product3012_specific_input.nil?
  hash['paymentProduct3013SpecificInput'] = @payment_product3013_specific_input.to_h unless @payment_product3013_specific_input.nil?
  hash['paymentProduct3208SpecificInput'] = @payment_product3208_specific_input.to_h unless @payment_product3208_specific_input.nil?
  hash['paymentProduct3209SpecificInput'] = @payment_product3209_specific_input.to_h unless @payment_product3209_specific_input.nil?
  hash['paymentProduct5002SpecificInput'] = @payment_product5002_specific_input.to_h unless @payment_product5002_specific_input.nil?
  hash['paymentProductId'] = @payment_product_id unless @payment_product_id.nil?
  hash['recurring'] = @recurring.to_h unless @recurring.nil?
  hash['returnUrl'] = @return_url unless @return_url.nil?
  hash['schemeReferenceData'] = @scheme_reference_data unless @scheme_reference_data.nil?
  hash['skipAuthentication'] = @skip_authentication unless @skip_authentication.nil?
  hash['subMerchant'] = @sub_merchant.to_h unless @sub_merchant.nil?
  hash['threeDSecure'] = @three_d_secure.to_h unless @three_d_secure.nil?
  hash['token'] = @token unless @token.nil?
  hash['tokenize'] = @tokenize unless @tokenize.nil?
  hash['transactionChannel'] = @transaction_channel unless @transaction_channel.nil?
  hash['unscheduledCardOnFileRequestor'] = @unscheduled_card_on_file_requestor unless @unscheduled_card_on_file_requestor.nil?
  hash['unscheduledCardOnFileSequenceIndicator'] = @unscheduled_card_on_file_sequence_indicator unless @unscheduled_card_on_file_sequence_indicator.nil?
  hash
end