Exception: OnlinePayments::SDK::ProblemDetailsException

Inherits:
ApiException
  • Object
show all
Defined in:
lib/onlinepayments/sdk/problem_details_exception.rb

Overview

Represents an error response from the payment platform containing problem details.

Instance Attribute Summary

Attributes inherited from ApiException

#error_id, #errors, #response_body, #status_code

Instance Method Summary collapse

Methods inherited from ApiException

#to_s

Constructor Details

#initialize(status_code, response_body, response) ⇒ ProblemDetailsException

Create a new ProblemDetailsException.



13
14
15
16
# File 'lib/onlinepayments/sdk/problem_details_exception.rb', line 13

def initialize(status_code, response_body, response)
  super(status_code, response_body, nil, nil, 'the payment platform returned a problem details error response')
  @response = response
end

Instance Method Details

#responseOnlinePayments::SDK::Domain::ProblemDetailsResponse?

The problem details response.



20
21
22
# File 'lib/onlinepayments/sdk/problem_details_exception.rb', line 20

def response
  @response
end