Class: OnlinePayments::SDK::Domain::AirlinePassenger
- Inherits:
-
DataObject
- Object
- DataObject
- OnlinePayments::SDK::Domain::AirlinePassenger
- Defined in:
- lib/onlinepayments/sdk/domain/airline_passenger.rb
Instance Attribute Summary collapse
-
#airline_loyalty_status ⇒ String
The current value of airline_loyalty_status.
-
#country_code ⇒ String
The current value of country_code.
-
#date_of_birth ⇒ String
The current value of date_of_birth.
-
#first_name ⇒ String
The current value of first_name.
-
#passenger_type ⇒ String
The current value of passenger_type.
-
#surname ⇒ String
The current value of surname.
-
#surname_prefix ⇒ String
The current value of surname_prefix.
-
#title ⇒ Object
deprecated
Deprecated.
This field is not used by any payment product Title of the passenger (this property is used for fraud screening on the payment platform)
Instance Method Summary collapse
Methods inherited from DataObject
Instance Attribute Details
#airline_loyalty_status ⇒ String
Returns the current value of airline_loyalty_status.
17 18 19 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 17 def airline_loyalty_status @airline_loyalty_status end |
#country_code ⇒ String
Returns the current value of country_code.
17 18 19 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 17 def country_code @country_code end |
#date_of_birth ⇒ String
Returns the current value of date_of_birth.
17 18 19 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 17 def date_of_birth @date_of_birth end |
#first_name ⇒ String
Returns the current value of first_name.
17 18 19 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 17 def first_name @first_name end |
#passenger_type ⇒ String
Returns the current value of passenger_type.
17 18 19 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 17 def passenger_type @passenger_type end |
#surname ⇒ String
Returns the current value of surname.
17 18 19 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 17 def surname @surname end |
#surname_prefix ⇒ String
Returns the current value of surname_prefix.
17 18 19 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 17 def surname_prefix @surname_prefix end |
#title ⇒ Object
This field is not used by any payment product Title of the passenger (this property is used for fraud screening on the payment platform)
17 18 19 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 17 def title @title end |
Instance Method Details
#from_hash(hash) ⇒ Object
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 50 def from_hash(hash) super if hash.has_key? 'airlineLoyaltyStatus' @airline_loyalty_status = hash['airlineLoyaltyStatus'] end if hash.has_key? 'countryCode' @country_code = hash['countryCode'] end if hash.has_key? 'dateOfBirth' @date_of_birth = hash['dateOfBirth'] end if hash.has_key? 'firstName' @first_name = hash['firstName'] end if hash.has_key? 'passengerType' @passenger_type = hash['passengerType'] end if hash.has_key? 'surname' @surname = hash['surname'] end if hash.has_key? 'surnamePrefix' @surname_prefix = hash['surnamePrefix'] end if hash.has_key? 'title' @title = hash['title'] end end |
#to_h ⇒ Hash
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/onlinepayments/sdk/domain/airline_passenger.rb', line 37 def to_h hash = super hash['airlineLoyaltyStatus'] = @airline_loyalty_status unless @airline_loyalty_status.nil? hash['countryCode'] = @country_code unless @country_code.nil? hash['dateOfBirth'] = @date_of_birth unless @date_of_birth.nil? hash['firstName'] = @first_name unless @first_name.nil? hash['passengerType'] = @passenger_type unless @passenger_type.nil? hash['surname'] = @surname unless @surname.nil? hash['surnamePrefix'] = @surname_prefix unless @surname_prefix.nil? hash['title'] = @title unless @title.nil? hash end |